import sys

import autograder.api.common
import autograder.api.user.auth

KEY_SUCCESS = 'success'
KEY_FOUND_USER = 'found-user'

def run(arguments):
    config_data = autograder.api.common.parse_config(arguments)
    config_data['email'] = arguments.email
    config_data['user-pass'] = arguments.userpass

    success, result = autograder.api.user.auth.send(arguments.server, config_data)

    if (not success):
        print(result)
        return 1

    if (not result[KEY_FOUND_USER]):
        print("No matching user found.")
        return 0

    if (result[KEY_SUCCESS]):
        print("Authentication successful.")
    else:
        print("Authentication failed.")

    return 0

def _get_parser():
    parser = autograder.api.common.get_argument_parser(description =
            'Authenticate as a user in this course.')

    parser.add_argument('email', metavar = 'EMAIL',
        action = 'store', type = str,
        help = 'The email of the user to auth.')

    parser.add_argument('userpass', metavar = 'PASS',
        action = 'store', type = str,
        help = 'The password of the user to auth.')

    return parser

def main():
    return run(_get_parser().parse_args())

if (__name__ == '__main__'):
    sys.exit(main())



import sys

import autograder.api.common
import autograder.api.user.list

HEADERS = ['email', 'name', 'role']

def run(arguments):
    config_data = autograder.api.common.parse_config(arguments)
    success, result = autograder.api.user.list.send(arguments.server, config_data)

    if (not success):
        print(result)
        return 1

    if (len(result) == 0):
        print("No users found.")
        return 0

    print("\t".join(HEADERS))

    for user in result:
        row = [user[key] for key in HEADERS]
        print("\t".join([str(value) for value in row]))

    return 0

def _get_parser():
    parser = autograder.api.common.get_argument_parser(description =
            'Get the users in this course.')

    return parser

def main():
    return run(_get_parser().parse_args())

if (__name__ == '__main__'):
    sys.exit(main())



import unittest
import sys

import autograder.api.history
import autograder.api.peek
import autograder.assignment
import autograder.question
import tests.server

SERVER_URL = "http://127.0.0.1:%s" % (tests.server.PORT)
FORMAT_STR = "\n--- Expected ---\n%s\n--- Actual ---\n%s\n---\n"

TEST_CREDENTIALS = {
    'user': 'user@test.com',
    'pass': 'password123',
    'course': 'COURSE101',
    'assignment': 'hw0',
}

@unittest.skipUnless(sys.platform.startswith('linux'), 'linux only (multiprocessing)')
class TestAPI(unittest.TestCase):
    """
    Test API calls by mocking a server.
    """

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self._server_process = None

    def setUp(self):
        self._server_process = tests.server.start()

    def tearDown(self):
        tests.server.stop(self._server_process)
        self._server_process = None

    def test_peek_base(self):
        success, response = autograder.api.peek.send(SERVER_URL, TEST_CREDENTIALS.copy())

        if (not success):
            self.fail("Peek request returned a failure: '%s'." % (response))

        expected = autograder.assignment.GradedAssignment(
            name = 'HW0',
            questions = [
                autograder.question.GradedQuestion(
                    name = 'Q1', max_points = 1, score = 1, message = ''
                ),
                autograder.question.GradedQuestion(
                    name = 'Q2', max_points = 1, score = 1, message = ''
                ),
                autograder.question.GradedQuestion(
                    name = 'Style', max_points = 0, score = 0, message = 'Style is clean!'
                ),
            ],
        )

        self.assertEquals(response, expected, FORMAT_STR % (expected.string(4), response.string(4)))

    def test_history_base(self):
        success, response = autograder.api.history.send(SERVER_URL, TEST_CREDENTIALS.copy())

        if (not success):
            self.fail("History request returned a failure: '%s'." % (response))

        expected = [
            {
                "id": "COURSE101::hw0::user@test.com::1",
                "message": "",
                "max_points": 2,
                "score": 1,
                "grading_start_time": "2023-09-25T22:50:54.225052Z"
            },
            {
                "id": "COURSE101::hw0::user@test.com::2",
                "message": "",
                "max_points": 2,
                "score": 1,
                "grading_start_time": "2023-09-25T22:51:54.225052Z"
            },
        ]

        self.assertEquals(response, expected)



import sys

import autograder.api.common
import autograder.api.user.add

KEY_SUCCESS = 'success'
KEY_FOUND_USER = 'found-user'

def run(arguments):
    config_data = autograder.api.common.parse_config(arguments)

    config_data['email'] = arguments.email
    config_data['new-pass'] = arguments.newpass
    config_data['name'] = arguments.name
    config_data['role'] = arguments.role
    config_data['force'] = arguments.force
    config_data['send-email'] = arguments.sendemail

    if ((arguments.newpass == '') and (not arguments.sendemail)):
        print("You must send an email if you do not specify a password.")
        return 1

    success, result = autograder.api.user.add.send(arguments.server, config_data)

    if (not success):
        print(result)
        return 1

    if (result['user-exists']):
        print("ERROR: User already exists and --force was not used.")
        return 1

    print("User added.")

    return 0

def _get_parser():
    parser = autograder.api.common.get_argument_parser(description =
            'Add a user to this course.')

    parser.add_argument('email', metavar = 'EMAIL',
        action = 'store', type = str,
        help = 'The email of the user to add.')

    parser.add_argument('--new-pass', dest = 'newpass',
        action = 'store', type = str, default = '',
        help = 'The password of the user to add.'
            + ' If empty, the server will generate a password'
            + ' (--send-email is required in this case).')

    parser.add_argument('--name', dest = 'name',
        action = 'store', type = str, default = '',
        help = 'Name of the user to add (defaults to the email).')

    parser.add_argument('--role', dest = 'role',
        action = 'store', type = str, default = 'student',
        help = 'Role of the user to add (defaults to student).')

    parser.add_argument('--force', dest = 'force',
        action = 'store_true', default = False,
        help = 'Overwrite any existing users (default: %(default)s).')

    parser.add_argument('--send-email', dest = 'sendemail',
        action = 'store_true', default = False,
        help = 'Send an email to the user being added.'
            + ' Required if a password is generated (default: %(default)s).')

    return parser

def main():
    return run(_get_parser().parse_args())

if (__name__ == '__main__'):
    sys.exit(main())
